@@ -72,7 +72,8 @@ class MetadataClient(
             ret_msg = "The proposal doesn't match this DAQ instance " \
                       "configured list of allowed instruments!"
             logging.warning(ret_msg)
-            resp['info'] = ret_msg
+
+            resp['info'] = 'Error getting proposal'
             resp['app_info'] = ret_msg
             resp['data'] = {}
 
