@@ -255,6 +255,63 @@ class ProposalTest(ModuleBase, unittest.TestCase):
         result9 = Proposal.delete_by_id(self.mdc_client, proposal_id)
         self.assert_delete_error(MODULE_NAME, result9, RESOURCE_NOT_FOUND)
 
+    def test_existing_proposal_api(self):
+        proposal_2 = {
+            PROPOSAL: {
+                'id': -2,
+                'number': 900061,
+                'title': 'DO NOT DELETE - CONTROLS TEST PROPOSAL 900061',
+                # 'abstract': '',
+                # 'url': 'https://www.xfel.eu/cas_robot_framework_test',
+                # 'instrument_id': '1',
+                'instrument_identifier': 'SPB',
+                # 'instrument_cycle_id': '-1',
+                # 'principal_investigator_id': '-7',
+                # 'main_proposer_id': '-7',
+                # 'orig_repository_id': -1,
+                'flg_beamtime_status': 'R'
+            }
+        }
+
+        expect = proposal_2[PROPOSAL]
+        prop_number = expect['number']
+
+        #
+        # Get entry by number
+        #
+        result1 = Proposal.get_by_number(self.mdc_client, prop_number)
+        received = result1['data']
+
+        # Test matching fields
+        self.assertEqual(expect['id'], received['id'], 'proposal id')
+        self.assertEqual(expect['number'], received['number'],
+                         'proposal number')
+        self.assertEqual(expect['title'], received['title'], 'proposal title')
+        self.assertEqual(expect['instrument_identifier'],
+                         received['instrument_identifier'],
+                         'proposal instrument_identifier')
+        self.assertEqual(expect['flg_beamtime_status'],
+                         received['flg_beamtime_status'],
+                         'proposal flg_beamtime_status')
+
+        #
+        # Get entry by number DAQ Info
+        #
+        result2 = Proposal.get_by_number_daq_info(self.mdc_client, prop_number)
+        received = result2['data']
+
+        # Test matching fields
+        self.assertEqual(expect['id'], received['id'], 'proposal id')
+        self.assertEqual(expect['number'], received['number'],
+                         'proposal number')
+        self.assertEqual(expect['title'], received['title'], 'proposal title')
+        self.assertEqual(expect['instrument_identifier'],
+                         received['instrument_identifier'],
+                         'proposal instrument_identifier')
+        self.assertEqual(expect['flg_beamtime_status'],
+                         received['flg_beamtime_status'],
+                         'proposal flg_beamtime_status')
+
     #
     # fields_validation
     #
